# Inputs

## 1.song_path 
## 2.songwithTime_path 


# Outputs
# timestamp list

# Installation:
## pip install lyric_matcher


## from lyricsmatcher import lyrics_matcher
## example
## lyrics_section_path = ''
## lyrics_timestamp_path = ''
## t = lyrics_matcher.lyrics_matcher(lyrics_section_path, lyrics_timestamp_path )